@@ -23,7 +23,7 @@ def setup():
     
 if not util.is_package("es_core_news_md"):
     subprocess.run("python -m spacy download es_core_news_md")
-    print("...instalando el modelo de leguanje 'es_core_news_md', porfavor vuelva a importar la libreria")
+    print("...instalando el modelo de leguanje 'es_core_news_md', porfavor reiniciar el kernel y vuelva a importar la libreria")
 else:
     setup()
 
@@ -37,7 +37,7 @@ def get_keywords(dataFrame):
     for index,rows in dataFrame.iterrows():
         text=rows["text"]
         filteredText=''.strip()
-        tokens = nlp(text)
+        tokens = ngram_vars["nlp"](text)
         '''tokens = [token
                  for token in tokens
                  if not token.is_stop and not token.is_punct]'''
@@ -45,7 +45,7 @@ def get_keywords(dataFrame):
             if token.pos_ == "NOUN" :
                 filteredText=filteredText+str(token.text.lower().strip())+","
                 
-        matches = matcher(tokens)
+        matches = ngram_vars["matcher"](tokens)
         for mach_id, start, end in matches:
             span = tokens[start:end]
             filteredText=filteredText+str(span.text.lower().strip())+","
@@ -78,15 +78,15 @@ def calculateDist(dataset,group_by="month"):
     dataset_=dataset.copy()
     dataset_["month"]=dataset_['date'].apply(lambda x: x.split("-")[1])
     dataset_["year"]=dataset_['date'].apply(lambda x: x.split("-")[0])
-    gb_dataset=group_by_date(dataset_, granularity)
+    gb_dataset=group_by_date(dataset_, group_by)
     sophia2_ngram_struct = {}
-    if granularity == "day":
+    if group_by == "day":
         for key, ds in gb_dataset:
             sophia2_ngram_struct[key.strftime("%Y/%m/%d")] = get_frequency(ds)
-    elif granularity == "month":
+    elif group_by == "month":
         for (month,year), ds in gb_dataset:
             sophia2_ngram_struct[(str(year)+"/"+str(month))] = get_frequency(ds)
-    elif granularity == "year":
+    elif group_by == "year":
         for year, ds in gb_dataset:
             sophia2_ngram_struct[str(year)] = get_frequency(ds)
     else: return "Wrong granularity parameter, please use 'day', 'month' or 'year' as granularity parameter instead of "+granularity
